
Log TLS connection failures
-------

**Description:**

Failing TLS connections should always be logged. This is a great indicator that 'something' is wrong.


**Solution:**

Verify that backend TLS connection failures are logged.

	
